@@ -1567,7 +1567,8 @@ class SQLCli(object):
                 else:
                     full_text = full_text + '\n' + text
                 # 判断SQL语句是否已经结束
-                (ret_bSQLCompleted, ret_SQLSplitResults, ret_SQLSplitResultsWithComments) = SQLAnalyze(full_text)
+                (ret_bSQLCompleted, ret_SQLSplitResults, ret_SQLSplitResultsWithComments, ret_SQLFlags) = \
+                    SQLAnalyze(full_text)
                 if ret_bSQLCompleted:
                     # SQL 语句已经结束
                     break
@@ -1673,7 +1674,8 @@ class SQLCli(object):
                             data = fp.read()
                         file_md5 = hashlib.md5(data).hexdigest()
                         if file_md5 != m_driver_filemd5.strip():
-                            print("Driver [" + m_driversection + "] consistent check failed.")
+                            print("Driver [" + m_driversection + "] consistent check failed. "
+                                                                 "Remote MD5=[" + str(file_md5) + "]")
                         else:
                             print("Driver [" + m_driversection + "] is up-to-date.")
                     else:
